==> wowit-0.3.23.tar.gz: lib/Widget/baseWidgets.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wowit/Controller/baseController.dart';

abstract class BaseWidget<T extends BaseController> extends GetWidget{



  BaseWidget(BaseController baseController,{String tag }) {
    Get.put(baseController as T, tag: tag);
  }
  T getController<T>() {
    return Get.find<T>();
  }

  @override
  Widget build(BuildContext context) {
    return this.getWidget(context);
  }

  Widget getWidget(BuildContext context) {
    return GetBuilder(
      init: Get.find<T>(),
      initState: (_) async {
        Get.find<T>().initStateGetX();
      },
      builder: (_) {
       var baseController =  Get.find<T>() ;
        printInfo(info: 'GetWidget start with Controller: ' + baseController.toString());
        var cachedData = baseController.getData();
        if (cachedData.length == 0) {
          return new FutureBuilder(
            future: baseController.loadData(),
            builder: (context,
                AsyncSnapshot<Map<String, List<Map<String, Object>>>>
                snapshot) {
              printInfo(info: 'GetWidget rebuild new data');

              if (snapshot.connectionState == ConnectionState.waiting) {
                printInfo(info: "ConnectionState.waiting return getSkeletonsView");
                return this.getSkelectonView(context);
              } else if (snapshot.data == null || snapshot.hasError) {
                printInfo(info: "Has error return getErrorView message: " + snapshot.error.toString());
                return this.getErrorView(snapshot);
              } else if (snapshot.data.length == 0) {
                printInfo(info: "Data is empty data.length == 0 return getEmptyView");
                return this.getEmptyView();
              }
              printInfo(info: "SetData to this.baseController item count: " +snapshot.data.length.toString());
              baseController.setData(snapshot.data);
              printInfo(info: "Done process return getMainView with Controller: " +baseController.toString());
              return this.getMainView(context, snapshot.data, baseController);
            },
          );
        } else {
          printInfo(info: 'GetWidget rebuild old data');
          return this.getMainView(context, cachedData,baseController);
        }
      },
    );
  }

  Widget getSkelectonView(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.only(left: 10),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Row(
            children: [
              Expanded(
                flex: 6,
                child: Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Container(
                    height: 150,
                    decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(10),
                        color: Colors.grey[100]),
                  ),
                ),
              ),
              Expanded(
                flex: 3,
                child: Column(
                  children: [
                    Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Container(
                        height: 67,
                        decoration: BoxDecoration(
                            borderRadius: BorderRadius.circular(10),
                            color: Colors.grey[100]),
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Container(
                        height: 67,
                        decoration: BoxDecoration(
                            borderRadius: BorderRadius.circular(10),
                            color: Colors.grey[100]),
                      ),
                    ),
                  ],
                ),
              )
            ],
          ),
          Padding(
            padding:
            const EdgeInsets.only(top: 8, right: 8, left: 8, bottom: 8),
            child: Container(
              height: 20,
              width: MediaQuery.of(context).size.width,
              decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(10),
                  color: Colors.grey[100]),
            ),
          ),
          Padding(
            padding:
            const EdgeInsets.only(top: 8, right: 20, left: 8, bottom: 8),
            child: Container(
              height: 20,
              width: MediaQuery.of(context).size.width / 1.5,
              decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(10),
                  color: Colors.grey[100]),
            ),
          )
        ],
      ),
    );
  }

  Widget getErrorView(
      AsyncSnapshot<Map<String, List<Map<String, Object>>>> snapshot) {
    return Center(
      child:
      Image.asset("assets/images/404-error.png", height: 100, width: 100),
    );
  }

  Widget getEmptyView() {
    return Center(
      child:
      Image.asset("assets/images/emptyFolder.png", height: 100, width: 100),
    );
  }

  Widget getMainView(
      BuildContext context, Map<String, List<Map<String, Object>>> data, BaseController controller);

}

==> wowit-0.3.32.tar.gz: lib/Widget/baseWidgets.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wowit/Controller/baseController.dart';

abstract class BaseWidget<T extends BaseController> extends GetWidget{



  BaseWidget(BaseController baseController,{String tag }) {
    Get.put(baseController as T, tag: tag);
  }
  T getController<T>() {
    return Get.find<T>();
  }

  @override
  Widget build(BuildContext context) {
    return this._getWidget(context);
  }

  void initStateGetX() async {}


  Widget _getWidget(BuildContext context) {
    return GetBuilder(
      init: Get.find<T>(),
      initState: (_) async {
        this.initStateGetX();
      },
      builder: (_) {
       var baseController =  Get.find<T>() ;
        printInfo(info: 'GetWidget start with Controller: ' + baseController.toString());
        var cachedData = baseController.getData();
        if (cachedData==null || cachedData.length == 0) {
          return new FutureBuilder(
            future: baseController.loadData(),
            builder: (context,
                AsyncSnapshot<Map<String, List<Map<String, Object>>>>
                snapshot) {
              printInfo(info: 'GetWidget rebuild new data');

              if (snapshot.connectionState == ConnectionState.waiting) {
                printInfo(info: "ConnectionState.waiting return getSkeletonsView");
                return this.getSkelectonView(context);
              } else if (snapshot.hasError) {
                printInfo(info: "Has error return getErrorView message: " + snapshot.error.toString());
                return this.getErrorView(snapshot);
              } else if (snapshot.data != null && snapshot.data.length == 0) {
                printInfo(info: "Data is empty data.length == 0 return getEmptyView");
                return this.getEmptyView();
              }
              baseController.setData(snapshot.data);
              printInfo(info: "Done process return getMainView with Controller: " +baseController.toString());
              return this.getMainView(context, snapshot.data, baseController);
            },
          );
        } else {
          printInfo(info: 'GetWidget rebuild old data');
          return this.getMainView(context, cachedData,baseController);
        }
      },
    );
  }

  Widget getSkelectonView(BuildContext context) {
    printInfo(info: "getSkelectonView: " + context.toString());

    return Padding(
      padding: const EdgeInsets.only(left: 10),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Row(
            children: [
              Expanded(
                flex: 6,
                child: Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Container(
                    height: 150,
                    decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(10),
                        color: Colors.grey[100]),
                  ),
                ),
              ),
              Expanded(
                flex: 3,
                child: Column(
                  children: [
                    Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Container(
                        height: 67,
                        decoration: BoxDecoration(
                            borderRadius: BorderRadius.circular(10),
                            color: Colors.grey[100]),
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Container(
                        height: 67,
                        decoration: BoxDecoration(
                            borderRadius: BorderRadius.circular(10),
                            color: Colors.grey[100]),
                      ),
                    ),
                  ],
                ),
              )
            ],
          ),
          Padding(
            padding:
            const EdgeInsets.only(top: 8, right: 8, left: 8, bottom: 8),
            child: Container(
              height: 20,
              width: MediaQuery.of(context).size.width,
              decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(10),
                  color: Colors.grey[100]),
            ),
          ),
          Padding(
            padding:
            const EdgeInsets.only(top: 8, right: 20, left: 8, bottom: 8),
            child: Container(
              height: 20,
              width: MediaQuery.of(context).size.width / 1.5,
              decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(10),
                  color: Colors.grey[100]),
            ),
          )
        ],
      ),
    );
  }

  Widget getErrorView(
      AsyncSnapshot<Map<String, List<Map<String, Object>>>> snapshot) {
    printInfo(info: "getErrorView: " + snapshot.error);

    return Center(
      child:
      Image.asset("assets/images/404-error.png", height: 100, width: 100),
    );
  }

  Widget getEmptyView() {
    printInfo(info: "getEmptyView");
    return Center(
      child:
      Image.asset("assets/images/emptyFolder.png", height: 100, width: 100),
    );
  }

  Widget getMainView(
      BuildContext context, Map<String, List<Map<String, Object>>> data, BaseController controller);

}
